==> humhub-1.6.3.tar.gz: humhub-1.6.3/protected/humhub/modules/admin/messages/fa-IR/user.php <==
<?php
return array (
  '<strong>Information</strong>' => '<strong>اطلاعات</strong>',
  '<strong>Settings</strong> and Configuration' => '<strong>تنظیمات</strong> و پیکربندی',
  '<strong>User</strong> administration' => 'مدیریت <strong>کاربران</strong>',
  'Accept user: <strong>{displayName}</strong> ' => 'پذیرش کاربر: <strong>{displayName}</strong>',
  'Account Request for \'{displayName}\' has been approved.' => 'درخواست حساب کاربری برای \'{displayname}\' تاییدشده‌است.',
  'Account Request for \'{displayName}\' has been declined.' => 'درخواست حساب کاربری برای \'{displayname}\' ردشده‌است.',
  'Actions' => 'عملیات',
  'Active users' => 'کاربران فعال',
  'Add Groups...' => 'افزودن گروه‌ها...',
  'Add new category' => 'افزودن رده‌ی جدید',
  'Add new field' => 'افزودن فیلد جدید',
  'Add new group' => 'افزودن گروه جدید',
  'Add new members...' => 'افزودن اعضای جدید...',
  'Add new user' => 'افزودن کاربر جدید',
  'All the personal data of this user will be irrevocably deleted.' => '',
  'Allow limited access for non-authenticated users (guests)' => 'به کاربرانی که هویتشان تایید نشده (کاربران مهمان) اجازه‌ی دسترسی محدود بده.',
  'Anonymous users can register' => 'کاربران ناشناس می‌توانند ثبت نام کنند',
  'Are you really sure that you want to disable this user?' => '',
  'Are you really sure that you want to enable this user?' => '',
  'Are you really sure that you want to impersonate this user?' => '',
  'Are you sure that you want to delete following user?' => '',
  'Cancel' => 'انصراف',
  'Click here to review' => 'برای بازبینی اینجا کلیک کنید.',
  'Confirm user deletion' => '',
  'Could not load category.' => 'رده بارگذاری نشد.',
  'Create new group' => 'ایجاد گروه جدید',
  'Create new profile category' => 'ایجاد رده‌ی پروفایل جدید',
  'Create new profile field' => 'ایجاد فیلد جدید برای پروفایل',
  'Decline & delete user: <strong>{displayName}</strong>' => 'رد و حذف کاربر: <strong>{displayName}</strong>',
  'Default content of the registration approval email' => '',
  'Default content of the registration denial email' => '',
  'Default user group for new users' => 'گروه کاربری پیش‌فرض برای کاربران جدید',
  'Default user idle timeout, auto-logout (in seconds, optional)' => 'زمان بیکاری پیش‌فرض برای کاربران، خروج خودکار (ثانیه، دلخواه)',
  'Default user profile visibility' => 'نمایش پیش‌فرض پروفایل کاربر',
  'Delete' => 'حذف',
  'Delete all contributions of this user' => '',
  'Delete invitation' => 'حذف دعوت',
  'Delete invitation?' => 'حذف دعوت؟',
  'Delete spaces which are owned by this user' => 'حذف انجمن‌هایی که این کاربر مالکشان است',
  'Deleted invitation' => 'دعوت حذف شده',
  'Deleted users' => 'کاربران حذف شده',
  'Disable' => 'غیرفعال',
  'Disabled' => 'غیرفعال شده',
  'Disabled users' => 'کاربران غیرفعال شده',
  'Do not change placeholders like {displayName} if you want them to be automatically filled by the system. To reset the email content fields with the system default, leave them empty.' => '',
  'Edit category' => 'ویرایش رده',
  'Edit profile category' => 'ویرایش رده پروفایل',
  'Edit profile field' => 'ویرایش فیلدهای پروفایل',
  'Edit user: {name}' => 'ویرایش کاربر: {name}',
  'Enable' => 'فعال',
  'Enabled' => 'فعال شده',
  'General' => 'کلی',
  'Group Manager' => 'مدیریت گروه‌ها',
  'Group not found!' => 'گروه یافت نشد!',
  'Group user not found!' => 'گروه كاربری يافت نشد',
  'Groups' => 'گروه‌ها',
  'Here you can create or edit profile categories and fields.' => 'اینجا می‌توانید رده پروفایل‌ها  و فیلدهای پروفایل‌ها را مدیریت کنید',
  'If this option is not selected, the ownership of the spaces will be transferred to your account.' => '',
  'Impersonate' => '',
  'Include captcha in registration form' => '',
  'Invite not found!' => '',
  'LDAP' => 'LDAP',
  'Last login' => 'آخرین ورود',
  'List pending registrations' => '',
  'Manage group: {groupName}' => 'مدیریت گروه: {groupName}',
  'Manage groups' => 'مدیریت گروه‌ها',
  'Manage profile attributes' => 'مدیریت ویژگی‌های پروفایل‌ها',
  'Member since' => 'عضو از',
  'Members' => 'اعضا',
  'Members can invite external users by email' => 'اعضا می‌توانند کاربران بیرونی را با ایمیل دعوت کنند',
  'Message' => 'پیغام',
  'Min value is 20 seconds. If not set, session will timeout after 1400 seconds (24 minutes) regardless of activity (default session timeout)' => 'کمترین مقدار ۲۰ ثانیه است. اگر مشخص نشده باشد، نشست کاری پس از ۱۴۰۰ ثانیه (۲۴ دقیقه) بدون در نظر گرفتن فعالیت بسته‌خواهد شد (مدت زمان پیش‌فرض نشست کاری)',
  'New approval requests' => 'درخواست‌های تاییدیه‌ی جدید',
  'No' => 'نه',
  'No value found!' => 'هيچ مقداری يافت نشد!',
  'One or more user needs your approval as group admin.' => 'یک یا چند کاربر تایید شما را به عنوان مدیر گروه نیاز دارند.',
  'Only applicable when limited access for non-authenticated users is enabled. Only affects new users.' => 'فقط زمانی قابل اجراست که برای کاربران ثبت‌نشده دسترسی محدود وجود دارد. تنها روی کاربران جدید اثر می‌گذارد.',
  'Overview' => 'دیدکلی',
  'Pending approvals' => 'تاییدیه‌های در انتظار',
  'Pending user approvals' => 'کاربران در انتظار تایید',
  'Permanently delete' => 'حذف همیشگی',
  'Permissions' => 'مجوزها',
  'Profiles' => 'پروفایل‌ها',
  'Remove from group' => 'از گروه حذف کن',
  'Require group admin approval after registration' => 'نیاز به تایید مدیر پس از ثبت‌نام',
  'Resend invitation email' => 'بازفرستادن ایمیل دعوت',
  'Save' => 'ذخیره',
  'Search by name, email or id.' => 'جستجو با نام، ایمیل یا شناسه.',
  'Select Groups' => 'گروه‌ها را برگزینید',
  'Send & save' => 'فرستادن و ذخیره',
  'Send invitation email' => 'فرستادن ایمیل دعوت',
  'Send invitation email again?' => 'ایمیل دعوت را دوباره بفرستم؟',
  'Send invite' => 'فرستادن دعوت',
  'Settings' => 'تنظیمات',
  'Subject' => 'موضوع',
  'The following list contains all pending sign-ups and invites.' => '',
  'The following list contains all registered users awaiting an approval.' => 'فهرست زیر شامل کاربران ثبت‌شده‌ای است که در انتظار تایید هستند.',
  'The user is the owner of these spaces:' => '',
  'This overview contains a list of each registered user with actions to view, edit and delete users.' => 'این لیست دیدی کلی درباره کاربرهای عضو شده می‌دهد',
  'This user owns no spaces.' => '',
  'Unapproved' => 'تایید نشده',
  'User deletion process queued.' => '',
  'User is already a member of this group.' => '',
  'User not found!' => 'کاربر پیدا نشد!',
  'Users' => 'کاربران',
  'Users can be assigned to different groups (e.g. teams, departments etc.) with specific standard spaces, group managers and permissions.' => 'کاربران می توانند در گروه‌های متفاوتی با انجمن‌های خاص و اجازه‌های متفاوت عضو شوند',
  'Using this option any contributions (e.g. contents, comments or likes) of this user will be irrevocably deleted.' => '',
  'View profile' => 'نمایش پروفایل',
  'Visibility' => 'قابلیت مشاهده',
  'Visible for members only' => 'نمایان تنها برای اعضا',
  'Visible for members+guests' => 'نمایان برای اعضا+مهمانان',
  'Yes' => 'بله',
  'You can only delete empty categories!' => 'شما فقط گروه‌های خالی را می‌توانید حذف کنید!',
  'You cannot delete yourself!' => 'شما نمی‌توانید خودتان را حذف کنید!',
  'never' => 'هرگز',
);

==> humhub-1.8.1.tar.gz: humhub-1.8.1/protected/humhub/modules/admin/messages/fa-IR/user.php <==
<?php
return array (
  '<strong>Information</strong>' => '<strong>اطلاعات</strong>',
  '<strong>Profile</strong> Permissions' => '',
  '<strong>Settings</strong> and Configuration' => '<strong>تنظیمات</strong> و پیکربندی',
  '<strong>User</strong> administration' => 'مدیریت <strong>کاربران</strong>',
  '<strong>Warning:</strong> All individual profile permission settings are reset to the default values!' => '',
  'Accept user: <strong>{displayName}</strong> ' => 'پذیرش کاربر: <strong>{displayName}</strong>',
  'Account' => 'حساب',
  'Account Request for \'{displayName}\' has been approved.' => 'درخواست حساب کاربری برای \'{displayname}\' تاییدشده‌است.',
  'Account Request for \'{displayName}\' has been declined.' => 'درخواست حساب کاربری برای \'{displayname}\' ردشده‌است.',
  'Actions' => 'عملیات',
  'Active users' => 'کاربران فعال',
  'Add Groups...' => 'افزودن گروه‌ها...',
  'Add a separate page for the group to the directory.' => '',
  'Add new category' => 'افزودن رده‌ی جدید',
  'Add new field' => 'افزودن فیلد جدید',
  'Add new group' => 'افزودن گروه جدید',
  'Add new members...' => 'افزودن اعضای جدید...',
  'Add new user' => 'افزودن کاربر جدید',
  'Administrator group could not be deleted!' => '',
  'All open registration invitations were successfully deleted.' => '',
  'All the personal data of this user will be irrevocably deleted.' => '',
  'Allow' => 'اجازه بده',
  'Allow users to set individual permissions for their own profile?' => '',
  'Allow visitors limited access to content without an account (Adds visibility: "Guest")' => 'به کاربرانی که هویتشان تایید نشده (کاربران مهمان) اجازه‌ی دسترسی محدود بده.',
  'Applied to new or existing users without any other group membership.' => '',
  'Are you really sure that you want to disable this user?' => '',
  'Are you really sure that you want to enable this user?' => '',
  'Are you really sure that you want to impersonate this user?' => '',
  'Are you really sure? Users who are not assigned to another group are automatically assigned to the default group.' => '',
  'Are you sure that you want to delete following user?' => '',
  'Cancel' => 'انصراف',
  'Click here to review' => 'برای بازبینی اینجا کلیک کنید.',
  'Confirm user deletion' => '',
  'Could not load category.' => 'رده بارگذاری نشد.',
  'Create new group' => 'ایجاد گروه جدید',
  'Create new profile category' => 'ایجاد رده‌ی پروفایل جدید',
  'Create new profile field' => 'ایجاد فیلد جدید برای پروفایل',
  'Deactivate' => '',
  'Deactivate individual profile permissions?' => '',
  'Decline & delete user: <strong>{displayName}</strong>' => 'رد و حذف کاربر: <strong>{displayName}</strong>',
  'Default' => 'پيش‌فرض',
  'Default Profile Permissions' => '',
  'Default content of the registration approval email' => '',
  'Default content of the registration denial email' => '',
  'Default groups can not be deleted!' => '',
  'Default user idle timeout, auto-logout (in seconds, optional)' => 'زمان بیکاری پیش‌فرض برای کاربران، خروج خودکار (ثانیه، دلخواه)',
  'Default user profile visibility' => 'نمایش پیش‌فرض پروفایل کاربر',
  'Delete' => 'حذف',
  'Delete All' => '',
  'Delete all contributions of this user' => '',
  'Delete invitation' => 'حذف دعوت',
  'Delete invitation?' => 'حذف دعوت؟',
  'Delete spaces which are owned by this user' => 'حذف انجمن‌هایی که این کاربر مالکشان است',
  'Deleted invitation' => 'دعوت حذف شده',
  'Deleted users' => 'کاربران حذف شده',
  'Disable' => 'غیرفعال',
  'Disabled' => 'غیرفعال شده',
  'Disabled users' => 'کاربران غیرفعال شده',
  'Do not change placeholders like {displayName} if you want them to be automatically filled by the system. To reset the email content fields with the system default, leave them empty.' => '',
  'Edit category' => 'ویرایش رده',
  'Edit profile category' => 'ویرایش رده پروفایل',
  'Edit profile field' => 'ویرایش فیلدهای پروفایل',
  'Edit user: {name}' => 'ویرایش کاربر: {name}',
  'Enable' => 'فعال',
  'Enable individual profile permissions' => '',
  'Enabled' => 'فعال شده',
  'Group Manager' => 'مدیریت گروه‌ها',
  'Group not found!' => 'گروه یافت نشد!',
  'Group user not found!' => 'گروه كاربری يافت نشد',
  'Groups' => 'گروه‌ها',
  'Hello {displayName},<br><br>
Your account has been activated.<br><br>
Click here to login:<br>
{loginLink}<br><br>

Kind Regards<br>
{AdminName}<br><br>' => '',
  'Hello {displayName},<br><br>
Your account request has been declined.<br><br>

Kind Regards<br>
{AdminName} <br><br> ' => '',
  'Here you can create or edit profile categories and fields.' => 'اینجا می‌توانید رده پروفایل‌ها  و فیلدهای پروفایل‌ها را مدیریت کنید',
  'If individual profile permissions are not allowed, the following settings are unchangeable for all users. If individual profile permissions are allowed, the settings are only set as defaults that users can customise. The following entries are then displayed in the same form in the users profile settings:' => '',
  'If this option is not selected, the ownership of the spaces will be transferred to your account.' => '',
  'Impersonate' => '',
  'Include captcha in registration form' => '',
  'Invite not found!' => '',
  'Last login' => 'آخرین ورود',
  'List pending registrations' => '',
  'Make the group selectable at registration.' => '',
  'Manage group: {groupName}' => 'مدیریت گروه: {groupName}',
  'Manage groups' => 'مدیریت گروه‌ها',
  'Manage profile attributes' => 'مدیریت ویژگی‌های پروفایل‌ها',
  'Member since' => 'عضو از',
  'Members' => 'اعضا',
  'Members can invite external users by email' => 'اعضا می‌توانند کاربران بیرونی را با ایمیل دعوت کنند',
  'Message' => 'پیغام',
  'Min value is 20 seconds. If not set, session will timeout after 1400 seconds (24 minutes) regardless of activity (default session timeout)' => 'کمترین مقدار ۲۰ ثانیه است. اگر مشخص نشده باشد، نشست کاری پس از ۱۴۰۰ ثانیه (۲۴ دقیقه) بدون در نظر گرفتن فعالیت بسته‌خواهد شد (مدت زمان پیش‌فرض نشست کاری)',
  'New approval requests' => 'درخواست‌های تاییدیه‌ی جدید',
  'New users can register' => 'کاربران ناشناس می‌توانند ثبت نام کنند',
  'No' => 'نه',
  'No value found!' => 'هيچ مقداری يافت نشد!',
  'One or more user needs your approval as group admin.' => 'یک یا چند کاربر تایید شما را به عنوان مدیر گروه نیاز دارند.',
  'Only applicable when limited access for non-authenticated users is enabled. Only affects new users.' => 'فقط زمانی قابل اجراست که برای کاربران ثبت‌نشده دسترسی محدود وجود دارد. تنها روی کاربران جدید اثر می‌گذارد.',
  'Overview' => 'دیدکلی',
  'Password' => 'گذرواژه',
  'Pending approvals' => 'تاییدیه‌های در انتظار',
  'Pending user approvals' => 'کاربران در انتظار تایید',
  'Permanently delete' => 'حذف همیشگی',
  'Permissions' => 'مجوزها',
  'Profile Permissions' => '',
  'Profiles' => 'پروفایل‌ها',
  'Remove from group' => 'از گروه حذف کن',
  'Require group admin approval after registration' => 'نیاز به تایید مدیر پس از ثبت‌نام',
  'Resend invitation email' => 'بازفرستادن ایمیل دعوت',
  'Save' => 'ذخیره',
  'Search by name, email or id.' => 'جستجو با نام، ایمیل یا شناسه.',
  'Select Groups' => 'گروه‌ها را برگزینید',
  'Send & save' => 'فرستادن و ذخیره',
  'Send invitation email' => 'فرستادن ایمیل دعوت',
  'Send invitation email again?' => 'ایمیل دعوت را دوباره بفرستم؟',
  'Send invite' => 'فرستادن دعوت',
  'Send notifications to users when added to or removed from the group.' => '',
  'Settings' => 'تنظیمات',
  'Show group selection at registration' => '',
  'Subject' => 'موضوع',
  'The Space memberships of all group members will be updated. This may take up to several minutes.' => '',
  'The following list contains all pending sign-ups and invites.' => '',
  'The following list contains all registered users awaiting an approval.' => 'فهرست زیر شامل کاربران ثبت‌شده‌ای است که در انتظار تایید هستند.',
  'The selected invitations have been successfully deleted!' => '',
  'The user is the owner of these spaces:' => '',
  'This option allows you to determine whether users may set individual permissions for their own profiles.' => '',
  'This overview contains a list of each registered user with actions to view, edit and delete users.' => 'این لیست دیدی کلی درباره کاربرهای عضو شده می‌دهد',
  'This user owns no spaces.' => '',
  'Unapproved' => 'تایید نشده',
  'User deletion process queued.' => '',
  'User is already a member of this group.' => '',
  'User not found!' => 'کاربر پیدا نشد!',
  'Users' => 'کاربران',
  'Users can be assigned to different groups (e.g. teams, departments etc.) with specific standard spaces, group managers and permissions.' => 'کاربران می توانند در گروه‌های متفاوتی با انجمن‌های خاص و اجازه‌های متفاوت عضو شوند',
  'Using this option any contributions (e.g. contents, comments or likes) of this user will be irrevocably deleted.' => '',
  'View profile' => 'نمایش پروفایل',
  'Visible for members only' => 'نمایان تنها برای اعضا',
  'Visible for members+guests' => 'نمایان برای اعضا+مهمانان',
  'Yes' => 'بله',
  'You can only delete empty categories!' => 'شما فقط گروه‌های خالی را می‌توانید حذف کنید!',
  'You cannot delete yourself!' => 'شما نمی‌توانید خودتان را حذف کنید!',
  'never' => 'هرگز',
);
